//importing the properties from the d3
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';
//selecting the svg and retreiving its atrributes height and width
const svg = select('svg'); 
const width = +svg.attr('width');
const height = +svg.attr('height');
// Rendering the data
const render = data => { 
  const title = '  GDP value In India From 2009 TO 2022 '; // providing the title to the line chart 
  
  const xValue = d => +d.Year; //displaying the x values ie years 2009 to 2022
  const xAxisLabel = 'Year'; // labeling the x axis as year
  // displaying the y values ie from 0 to 4000 million 
  const yValue = d => d.IndiaGDP; 
  const yAxisLabel = 'IndiaGDP'; // labeling the y axis as IndiaGDP
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };// providing the margin for line chart
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
  // providing the complete set of values
    .domain(extent(data, xValue)) //returns the minimum and maximum value in an array from the given array using natural order.
    .range([0,innerWidth]) 
    .nice(); // it will round the values out
  
  const yScale = scaleLinear() // 
    .domain([0, max(data, yValue )])
    .range([innerHeight,0])//output bounds
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`)
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight) // to get axis position at bottom
    .tickPadding(20);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth) // to get axis position at left side
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis); //It appends a 'g' element to the SVG. which  is used to group SVG shapes together,
  	yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text') // for labeling the text
      .attr('class', 'axis-label')
      .attr('y', -100)
      .attr('x', -innerHeight / 4)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)//applying xaxis method to the g element
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text') // for x axis labeling
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  const lineGenerator = line() // it generrates horizantal and vertical lines for x and y axis
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d))); // provide coordinates in pixels
  
  g.append('path') // provides path to the line 
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
    console.log(lineGenerator(data))
  
  g.append('text') // for labeling the title of the line chart
      .attr('class', 'title')
      .attr('y', -20)
      .attr('x', innerWidth / 5)
      .text(title);
};
// getting the csv data uisng github url link for my data 
csv('https://gist.githubusercontent.com/prachow/a02d466980723b8e6269f233a946c2ca/raw/b535ae16cd5b65d902f8f901131959889e5da583/indiagdp.csv')
  .then(data => {
  	//console.log(data)
    data.forEach(d => {
    	d.IndiaGDP = +d.IndiaGDP;
      d.Year = new Date(d.Year)
    });
  console.log(data)
    render(data);
  });